@@ -4,9 +4,10 @@ import unittest
 import collections
 import pprint
 import math
+import inspect
 
 
-__version__ = '0.0.6'
+__version__ = '0.0.7'
 
 
 class Error(Exception):
@@ -16,6 +17,20 @@ class Error(Exception):
 TICK_INTERVAL_PADDING_RATIO = 0.1
 
 
+def memo1(f):
+    assert len(inspect.getargspec(f).args) == 1
+    cache = {}
+    def retf(x):
+        if x in cache:
+            return cache[x]
+        else:
+            retv = f(x)
+            cache[x] = retv
+            return retv
+    retf.cache = cache
+    return retf
+
+
 def _get_interval(lx):
     assert lx > 0
     dx = 10**(math.ceil(math.log10(lx)) - 1)
@@ -91,6 +106,8 @@ def list_2d(n_row, n_column, init=None):
             in range(n_row)]
 
 
+# TODO: listを返すバージョンも作る
+# TODO: 負の数でスキップを可能にする
 def make_fixed_format_parser(fields):
     """
     fields: (('density', 3, int),
